@@ -1,4 +1,5 @@
-from . import Game, GameConfig, register_game
+from . import register_game
+from .base import Game, GameConfig
 from kivy.uix.label import Label
 from kivy.uix.boxlayout import BoxLayout
 
